"""
Provides properties with information about ``behave_restful``.
"""

project = 'behave-restful'
version = '0.4'
release = '{version}.4'.format(version=version)
description = 'Implements Gherking language for REST services.'
copyright = '2017 Abantos'
author = 'Isaac Rodriguez'
author_email = 'oss.abantos@outlook.com'
url = 'https://github.com/behave-restful/behave-restful'
license = 'MIT'
keywords = 'rest bdd behave gherkin test automation testing'

classifiers = [
    'Development Status :: 1 - Planning',
    'Environment :: Console',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Software Development :: Testing :: Acceptance',
    'Topic :: Software Development :: Testing :: BDD',
]
