"""
All python modules in this folder are loaded by Behave Restful and the
implemented hooks are registered to be invoked at the correct time. You can
uncomment the hook you need and implement it or create a new hooks file in this
folder using this one as a base.
"""

# def before_all(context):
#     pass


# def after_all(context):
#     pass
    

# def before_feature(context, feature):
#     pass


# def after_feature(context, feature):
#     pass


# def before_scenario(context, scenario):
#     pass


# def after_scenario(context, scenario):
#     pass


# def before_step(context, step):
#     pass


# def after_step(context, step):
#     pass


# def before_tag(context, tag):
#     pass


# def after_tag(context, tag):
#     pass